@@ -2,7 +2,7 @@
 
 /*
  *   Copyright (c) 2001-2010 Aaron Turner <aturner at synfin dot net>
- *   Copyright (c) 2013-2016 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
+ *   Copyright (c) 2013-2017 Fred Klassen <tcpreplay at appneta dot com> - AppNeta
  *
  *   The Tcpreplay Suite of tools is free software: you can redistribute it 
  *   and/or modify it under the terms of the GNU General Public License as 
@@ -27,14 +27,6 @@
 extern "C" {
 #endif
 
-/*
- * structure to hold any data parsed from the packet by the decoder.
- */
-typedef struct jnpr_ether_extra_s {
-    ;
-} jnpr_ether_extra_t;
-
-
 /* we have no user config data */
 typedef struct jnpr_ether_config_s {
     /* sub-plugin context for the en10mb plugin */
